@@ -10,7 +10,7 @@
     :license: BSD, see LICENSE for more details.
 """
 
-nodeenv_version = '0.9.5'
+nodeenv_version = '0.9.6'
 
 import sys
 import os
@@ -102,8 +102,7 @@ def parse_args():
         usage="%prog [OPTIONS] ENV_DIR")
 
     parser.add_option(
-        '-n', '--node', dest='node',
-        metavar='NODE_VER', default=get_last_stable_node_version(),
+        '-n', '--node', dest='node', metavar='NODE_VER',
         help='The node.js version to use, e.g., '
         '--node=0.4.3 will use the node-v0.4.3 '
         'to create the new environment. The default is last stable version. '
@@ -567,8 +566,6 @@ def install_activate(env_dir, opt):
         writefile(file_path, content, append=need_append)
         os.chmod(file_path, mode_0755)
 
-    os.symlink("node", join(bin_dir, "nodejs"))
-
 
 def create_environment(env_dir, opt):
     """
@@ -654,6 +651,7 @@ def main():
     Entry point
     """
     opt, args = parse_args()
+    opt.node = opt.node or get_last_stable_node_version()
 
     if opt.list:
         print_node_versions()
